==> ngmap-1.14.16.jar: META-INF/resources/webjars/ngmap/1.14.16/CONTRIBUTORS.md <==
#Angularjs-Google-Maps Is Only Possible By;

<a href='https://github.com/allenhwkim' title='allenhwkim'><img src='https://avatars.githubusercontent.com/u/1437734?v=3' width='60px' /></a>
<a href='https://github.com/HamzaAzeem' title='HamzaAzeem'><img src='https://avatars.githubusercontent.com/u/5498973?v=3' width='60px' /></a>
<a href='https://github.com/Fangmingdu' title='Fangmingdu'><img src='https://avatars.githubusercontent.com/u/5725594?v=3' width='60px' /></a>
<a href='https://github.com/dlukez' title='dlukez'><img src='https://avatars.githubusercontent.com/u/1725353?v=3' width='60px' /></a>
<a href='https://github.com/AlexandreKilian' title='AlexandreKilian'><img src='https://avatars.githubusercontent.com/u/2519487?v=3' width='60px' /></a>
<a href='https://github.com/hokennethk' title='hokennethk'><img src='https://avatars.githubusercontent.com/u/9583804?v=3' width='60px' /></a>
<a href='https://github.com/prem-prakash' title='prem-prakash'><img src='https://avatars.githubusercontent.com/u/775409?v=3' width='60px' /></a>
<a href='https://github.com/stevenlundy' title='stevenlundy'><img src='https://avatars.githubusercontent.com/u/4694092?v=3' width='60px' /></a>
<a href='https://github.com/jpagand' title='jpagand'><img src='https://avatars.githubusercontent.com/u/2401332?v=3' width='60px' /></a>
<a href='https://github.com/jkornata' title='jkornata'><img src='https://avatars.githubusercontent.com/u/7041200?v=3' width='60px' /></a>
<a href='https://github.com/sposmen' title='sposmen'><img src='https://avatars.githubusercontent.com/u/1591405?v=3' width='60px' /></a>
<a href='https://github.com/mliu95' title='mliu95'><img src='https://avatars.githubusercontent.com/u/4820950?v=3' width='60px' /></a>
<a href='https://github.com/pmcochrane' title='pmcochrane'><img src='https://avatars.githubusercontent.com/u/7922620?v=3' width='60px' /></a>
<a href='https://github.com/pennysmith1' title='pennysmith1'><img src='https://avatars.githubusercontent.com/u/13732116?v=3' width='60px' /></a>
<a href='https://github.com/sebrojas14' title='sebrojas14'><img src='https://avatars.githubusercontent.com/u/1771574?v=3' width='60px' /></a>
<a href='https://github.com/simonh1000' title='simonh1000'><img src='https://avatars.githubusercontent.com/u/5256724?v=3' width='60px' /></a>
<a href='https://github.com/csdigi' title='csdigi'><img src='https://avatars.githubusercontent.com/u/43999?v=3' width='60px' /></a>
<a href='https://github.com/xavierjohn' title='xavierjohn'><img src='https://avatars.githubusercontent.com/u/1859710?v=3' width='60px' /></a>
<a href='https://github.com/kpgarrod' title='kpgarrod'><img src='https://avatars.githubusercontent.com/u/2155409?v=3' width='60px' /></a>
<a href='https://github.com/martinmicunda' title='martinmicunda'><img src='https://avatars.githubusercontent.com/u/1643606?v=3' width='60px' /></a>
## We Love You All

==> ngmap-1.17.1.jar: META-INF/resources/webjars/ngmap/1.17.1/CONTRIBUTORS.md <==
#Angularjs-Google-Maps Is Only Possible By;

<a href='https://github.com/allenhwkim' title='allenhwkim'><img src='https://avatars.githubusercontent.com/u/1437734?v=3' width='60px' /></a>
<a href='https://github.com/HamzaAzeem' title='HamzaAzeem'><img src='https://avatars.githubusercontent.com/u/5498973?v=3' width='60px' /></a>
<a href='https://github.com/Fangmingdu' title='Fangmingdu'><img src='https://avatars.githubusercontent.com/u/5725594?v=3' width='60px' /></a>
<a href='https://github.com/dlukez' title='dlukez'><img src='https://avatars.githubusercontent.com/u/1725353?v=3' width='60px' /></a>
<a href='https://github.com/Jonfor' title='Jonfor'><img src='https://avatars.githubusercontent.com/u/3246528?v=3' width='60px' /></a>
<a href='https://github.com/harm-less' title='harm-less'><img src='https://avatars.githubusercontent.com/u/6368074?v=3' width='60px' /></a>
<a href='https://github.com/AlexandreKilian' title='AlexandreKilian'><img src='https://avatars.githubusercontent.com/u/2519487?v=3' width='60px' /></a>
<a href='https://github.com/hokennethk' title='hokennethk'><img src='https://avatars.githubusercontent.com/u/9583804?v=3' width='60px' /></a>
<a href='https://github.com/prem-prakash' title='prem-prakash'><img src='https://avatars.githubusercontent.com/u/775409?v=3' width='60px' /></a>
<a href='https://github.com/stevenlundy' title='stevenlundy'><img src='https://avatars.githubusercontent.com/u/4694092?v=3' width='60px' /></a>
<a href='https://github.com/jpagand' title='jpagand'><img src='https://avatars.githubusercontent.com/u/2401332?v=3' width='60px' /></a>
<a href='https://github.com/jkornata' title='jkornata'><img src='https://avatars.githubusercontent.com/u/7041200?v=3' width='60px' /></a>
<a href='https://github.com/sposmen' title='sposmen'><img src='https://avatars.githubusercontent.com/u/1591405?v=3' width='60px' /></a>
<a href='https://github.com/aitboudad' title='aitboudad'><img src='https://avatars.githubusercontent.com/u/1753742?v=3' width='60px' /></a>
<a href='https://github.com/joakimkm' title='joakimkm'><img src='https://avatars.githubusercontent.com/u/6367074?v=3' width='60px' /></a>
<a href='https://github.com/mliu95' title='mliu95'><img src='https://avatars.githubusercontent.com/u/4820950?v=3' width='60px' /></a>
<a href='https://github.com/pmcochrane' title='pmcochrane'><img src='https://avatars.githubusercontent.com/u/7922620?v=3' width='60px' /></a>
<a href='https://github.com/pennysmith1' title='pennysmith1'><img src='https://avatars.githubusercontent.com/u/13732116?v=3' width='60px' /></a>
<a href='https://github.com/sebrojas14' title='sebrojas14'><img src='https://avatars.githubusercontent.com/u/1771574?v=3' width='60px' /></a>
<a href='https://github.com/simonh1000' title='simonh1000'><img src='https://avatars.githubusercontent.com/u/5256724?v=3' width='60px' /></a>
<a href='https://github.com/csdigi' title='csdigi'><img src='https://avatars.githubusercontent.com/u/43999?v=3' width='60px' /></a>
<a href='https://github.com/xavierjohn' title='xavierjohn'><img src='https://avatars.githubusercontent.com/u/1859710?v=3' width='60px' /></a>
<a href='https://github.com/kpgarrod' title='kpgarrod'><img src='https://avatars.githubusercontent.com/u/2155409?v=3' width='60px' /></a>
<a href='https://github.com/martinmicunda' title='martinmicunda'><img src='https://avatars.githubusercontent.com/u/1643606?v=3' width='60px' /></a>
## We Love You All
